@@ -17,7 +17,7 @@ from .misc import OrderedDict, cached_property, cache
 ppc = pp.pyparsing_common
 from .grammar import generate_grammar, separator as separator_grammar, \
                      delimitedList, line_end, optional_quote,\
-                     replace_whitechars
+                     replace_whitechars, White
 
 from ase.units import Rydberg
 import copy
@@ -63,7 +63,7 @@ class BaseType:
   def __init__(self, prefix:Union[str,None]=None, postfix:Union[str,None]=None,
                      format:str='', default_value:Any=None,
                      condition:Union[Callable[[Any], Union[bool,str]],None]=None,
-                     after_convert:Union[Callable[Any, Any],None]=None):
+                     after_convert:Union[Callable[[Any], Any],None]=None):
       """
       Create the object.
 
@@ -553,7 +553,7 @@ def type_from_type(type, format='', format_all=False):
 class Array(BaseType):
   """ A (numpy) array of values of one type """
 
-  delimiter=pp.White(' \t').suppress()
+  delimiter=White(' \t').suppress()
   delimiter_str = ' '
 
   def __init__(self, type, default_value=None,
@@ -570,16 +570,17 @@ class Array(BaseType):
     super().__init__(default_value=default_value, **kwargs)
     self.min_length = min_length or length
     self.max_length = max_length or length
-    grammar = self.type.grammar()
-    grammar = delimitedList(grammar, self.delimiter)
-    if self.as_list:
-       if callable(self.as_list):
+    with generate_grammar():
+      grammar = self.type.grammar()
+      grammar = delimitedList(grammar, self.delimiter)
+      if self.as_list:
+        if callable(self.as_list):
           grammar = grammar.setParseAction(lambda x: self.as_list(x.asList()))
-       else:
+        else:
           grammar = grammar.setParseAction(lambda x: [x.asList()])
-    else:
-       grammar.setParseAction(lambda x: self.convert(x.asList()))
-    grammar.setName(self.grammar_name())
+      else:
+        grammar.setParseAction(lambda x: self.convert(x.asList()))
+        grammar.setName(self.grammar_name())
     self._grammar = grammar
 
   def __str__(self):
@@ -640,7 +641,7 @@ class Array(BaseType):
 class SetOf(Array):
   """ Set of values of the same type. E.g. {1,2,3} """
 
-  delimiter = pp.Suppress(pp.Literal(',') | pp.Literal(';') | pp.White(' \t')).setName('[,; ]')
+  delimiter = pp.Suppress(pp.Literal(',') | pp.Literal(';') | White(' \t')).setName('[,; ]')
   delimiter_str = ','
 
   def __init__(self, type, **kwargs):
