@@ -1,3 +1,4 @@
+""" ARPES task input parameters definition """
 from ...common.grammar_types  import *
 from .sections import *
 from ..input_parameters_definitions import \
@@ -5,6 +6,7 @@ from ..input_parameters_definitions import \
     ValueDefinition as V, \
     SectionDefinition as Section
 
+#: ARPES task input parameters definition
 input_parameters = InputParameters(
     'arpes', [
     CONTROL('ARPES'),
