@@ -1,3 +1,10 @@
+""" Containers for configuration parameters of SPR-KKR task.
+
+These configuration parameters are supplied to SPR-KKR executables as input files.
+The containers are also the objects, that take care about executing the SPR-KKR
+executables.
+"""
+
 import os
 import io
 import tempfile
@@ -9,8 +16,18 @@ from ..outputs.readers.default import DefaultOutputReader
 from ..common.configuration_containers import RootConfigurationContainer
 from ..common.misc import lazy_value, OrderedDict
 import shutil
+from typing import Union
 
-def resolve_executable_postfix(postfix):
+def resolve_executable_postfix(postfix:Union[str,bool]):
+    """" Return the postfix, that is appended after the name of SPR-KKR executable.
+
+    Parameters
+    ----------
+    postfix
+      - If str is given, it is left as is.
+      - If True, return the content of SPRKKR_EXECUTABLE_SUFFIX environment variable
+      - If False, return ''
+    """
     if postfix is False:
         return ''
     if postfix is True:
@@ -18,6 +35,14 @@ def resolve_executable_postfix(postfix):
     return postfix
 
 class InputParameters(RootConfigurationContainer):
+  """ It holds the configuration values for a SPR-KKR task and run the task
+
+  This class is a ConfigurationContainer, thus, it holds the configuration values
+  for the task. Moreover, according to its definition, it can run the task -
+  execute the executable with proper parameters - and instantiate the result class,
+  which then parse the output of the task.
+  """
+
   def __init__(self, definition, inputfile=None, outputfile=False):
       super().__init__(definition)
       self._inputfile = inputfile
@@ -53,25 +78,30 @@ class InputParameters(RootConfigurationContainer):
       return cls._default_mpi_runner
 
   def mpi_runner(self, mpi):
-      """ Return a mpi runner according to the given parameter.
+      """ Return a shell command to execute a mpi task.
 
       Parameters
       ----------
-      mpi_runner: bool or str or list or int
-        If True is given, return the default mpi-runner
-        If False is given, no mpi-runner is returned.
-        If a string is given, it is interpreted as list of one item
-        If a list (of strings) is given, the user specified its own
-           runner, use it as is.
-        If an integer is given, it is interpreted as the number of
-           processes: the default mpi-runner is used, and the parameters
-           to specify the number of processes.
+      mpi_runner: Union[bool|str|list|int]
+
+
+        - If True is given, return the default mpi-runner
+        - If False is given, no mpi-runner is returned.
+        - If a string is given, it is interpreted as a list of one item
+        - If a list (of strings) is given, the user specified its own runner, use it as is
+          as the parameters for subprocess.run.
+        - If an integer is given, it is interpreted as the number of
+          processes: the default mpi-runner is used, and the parameters
+          to specify the number of processes.
 
       Return
       ------
       mpi_runner: list
-        List of strings with executable and parameters, e.g.
-        ['mpirun', '-np', '4']
+        List of strings with the executable and its parameters, e.g.
+
+        ::
+
+            ['mpirun', '-np', '4']
       """
       if mpi is False or not self._definition.mpi:
           return None
